@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package Email::MIME;
 # ABSTRACT: easy MIME message handling
-$Email::MIME::VERSION = '1.933';
+$Email::MIME::VERSION = '1.934';
 use Email::Simple 2.206; # header_raw
 use parent qw(Email::Simple);
 
@@ -397,8 +397,8 @@ sub debug_structure {
   $level ||= 0;
   my $rv = " " x (5 * $level);
   $rv .= "+ " . ($self->content_type || '') . "\n";
-  my @parts = $self->parts;
-  if (@parts > 1) { $rv .= $_->debug_structure($level + 1) for @parts; }
+  my @parts = $self->subparts;
+  $rv .= $_->debug_structure($level + 1) for @parts;
   return $rv;
 }
 
@@ -857,7 +857,7 @@ Email::MIME - easy MIME message handling
 
 =head1 VERSION
 
-version 1.933
+version 1.934
 
 =head1 SYNOPSIS
 
@@ -1233,7 +1233,7 @@ Simon Cozens <simon@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alex Vandiver Arthur Axel 'fREW' Schmidt Brian Cassidy David Steinbrunner Dotan Dimet Geraint Edwards Jesse Luehrs Kurt Anderson Matthew Horsfall (alh) memememomo Shawn Sorichetti Tomohiro Hosaka
+=for stopwords Alex Vandiver Arthur Axel 'fREW' Schmidt Brian Cassidy David Steinbrunner Dotan Dimet Geraint Edwards Jesse Luehrs Kurt Anderson Lance A. Brown Matthew Horsfall (alh) memememomo Shawn Sorichetti Tomohiro Hosaka
 
 =over 4
 
@@ -1271,6 +1271,10 @@ Kurt Anderson <kboth@drkurt.com>
 
 =item *
 
+Lance A. Brown <lance@bearcircle.net>
+
+=item *
+
 Matthew Horsfall (alh) <wolfsage@gmail.com>
 
 =item *
